#
# spec file for package reiser4progs
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           reiser4progs
Version:        1.1.0
Release:        2.4
%define lsuf	-1_1-0
Summary:        Utilities for Managing the Reiser4 File System
License:        GPL-2.0
Group:          System/Filesystems
Url:            http://sf.net/projects/reiser4/

Source:         http://downloads.sf.net/reiser4/%name-%version.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  libaal-devel
BuildRequires:  libuuid-devel
BuildRequires:  readline-devel
BuildRequires:  xz
# There is a dull test which involes gcc -static
BuildRequires:  glibc-devel-static
BuildRequires:  libaal-devel-static

%description
A set of commands for using the Reiser4 file system, including
mkfs.reiser4.

%package -n libreiser4%lsuf
Summary:        Reiser4 filesystem library
Group:          System/Libraries

%description -n libreiser4%lsuf

%package -n libreiser4-minimal%lsuf
Summary:        Minimal version of the Reiser4 filesystem library
Group:          System/Libraries

%description -n libreiser4-minimal%lsuf
libreiser4-minimal is a variant of the Reiser4 filesystem library
that uses a reduced footprint and which has certain features disabled
(plugin check, FNV1 hash, Rupasov hash, TEA hash and DEG hash). The
maximum supported path length in -minimal is 256 instead of 1024.

In openSUSE, all tunable features remain of libreiser4-minimal enabled.

%package -n librepair%lsuf
Summary:        Repair library for the Reiser4 filesystem
Group:          System/Libraries

%description -n librepair%lsuf

%package devel
Summary:        Header C files and static libs for the Reiser4 File System tools
Group:          Development/Libraries/C and C++
Requires:       libreiser4%lsuf = %version
Requires:       libreiser4-minimal%lsuf = %version
Requires:       librepair%lsuf = %version

%description devel
A set of header C files and static libraries for the Reiser4 file
system tools.

%prep
%setup -q

%build
#
# Disabling hashes only affects minimal library. The options are
# a recommendation from reiser4progs's shipped .spec file.
#
%configure --disable-static --enable-libminimal --disable-fnv1-hash \
	--disable-rupasov-hash --disable-tea-hash --disable-deg-hash
make %{?_smp_mflags}

%install
# paralel install cause missing file
make install DESTDIR="%buildroot"
rm -f "%buildroot/%_libdir"/*.la

%post   -n libreiser4%lsuf -p /sbin/ldconfig
%postun -n libreiser4%lsuf -p /sbin/ldconfig
%post   -n libreiser4-minimal%lsuf -p /sbin/ldconfig
%postun -n libreiser4-minimal%lsuf -p /sbin/ldconfig
%post   -n librepair%lsuf -p /sbin/ldconfig
%postun -n librepair%lsuf -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc BUGS COPYING ChangeLog NEWS README TODO
%_mandir/man8/*
%_sbindir/*reiser4

%files -n libreiser4%lsuf
%defattr(-,root,root)
%_libdir/libreiser4-1.1.so.0*

%files -n libreiser4-minimal%lsuf
%defattr(-,root,root)
%_libdir/libreiser4-minimal-1.1.so.0*

%files -n librepair%lsuf
%defattr(-,root,root)
%_libdir/librepair-1.1.so.0*

%files devel
%defattr(-,root,root)
%_includedir/reiser4/
%_includedir/repair/
%_libdir/lib*.so
%_datadir/aclocal/

%changelog
* Tue Sep  1 2015 jengelh@inai.de
- Update to new upstream release 1.1.0
  * Format release 4.0.1
  * Support checksum for formatted nodes
  * NODE41 format with 32-bit field for checksums
* Sun Jun 29 2014 jengelh@inai.de
- Update to new upstream release 1.0.9
  * discard option to mkfs -- discard device at filesystem creation
  time (for SSD drives)
* Fri Jun  7 2013 tchvatal@suse.com
- Use -j1 for install to avoid missing symlink creation.
  ppc and others force -j1 so install failed for them.
* Sat May  4 2013 jengelh@inai.de
- Update to new upstream release 1.0.8
  * Fixups in fsck.reiser4: repair a special kind of corruptions
  appeared due to software bugs in earlier kernels.
  * mkfs.reiser4 now enables intelligent compression with lzo1
  algorithm by default. If you want to create reiser4 without
  compression, then override the default plugin set with the
  "-o create=reg40" option.
* Fri Jan 23 2009 lmichnovic@suse.cz
- new version 1.0.7
* Mon Mar  3 2008 lmichnovic@suse.cz
- package added into BuildService [bnc#366250]
* Tue May 29 2007 lmichnovic@suse.cz
- split off devel sub-package
- not using %%run_ldconfig macro
* Sat May 26 2007 ro@suse.de
- added libaal-devel to buildreq
* Fri Apr 13 2007 lmichnovic@suse.cz
- not removing $RPM_BUILD_ROOT in install section
- not installing static libs *.la
* Fri Apr 13 2007 lmichnovic@suse.cz
- update to 1.0.6
  * Version control data is added into format40 disk format plugin.
  * Version control data is added into backup blocks.
  * Recover filesystems of both old and new formats - temporary.
  * UPDATE_BACKUP_IS_NEEDED is added -- handle correctly cases when
  * disk format is updated and backup blocks are not; fsck correctly.
  * Heir plugin SET (HSET) is added.
  * A lot of speedups.
  * Demos/busy program update: crypto compression test is added.
  * Compression plugin is added.
  * CryptoCompression plugin is adjusted to handle compressed files
  * Crypto-Compression Object plugins is added.
  * Fix the object creation: inherit always from the parent.
  * Fix the pset storage policy.
  * Compression tail item (ctail) plugin is added.
  * The full support for Crypto-Compression plugins is added
  into PluginSet and libreiser4 profile.
  * Crypto SD extention is added.
  * Bugfixes:
  - a lot of fixes in compression tail item plugin;
  - a lot of fixes in CryptoCompression object plugin;
  - a lot of fixes in common object plugin repair code;
  - in truncate, clubber, check_struct methods of all object
    plugins
  - check the path given on a symlink creation;
  - check the possible file position overflow;
  - handle the cluster size of ctail items correctly.
  - and many others
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Jan 12 2006 mjancar@suse.cz
- update to 1.0.5
* Mon Aug  1 2005 mjancar@suse.cz
- update to 1.0.4
* Thu Apr 14 2005 mjancar@suse.cz
- fix for gcc 4.0
* Thu Feb 24 2005 mjancar@suse.cz
- update to 1.0.3
* Thu Nov 11 2004 ro@suse.de
- fixed file list
* Wed Aug 25 2004 mjancar@suse.cz
- update to 1.0.1
* Fri Aug 13 2004 mjancar@suse.cz
- update to 0.5.6
* Thu Feb 26 2004 mjancar@suse.cz
- updater to 0.5.1
* Tue Feb  3 2004 mjancar@suse.cz
- update to 0.4.20
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Tue Oct 14 2003 mjancar@suse.cz
- use %%{run_ldconfig}
* Tue Oct 14 2003 mjancar@suse.cz
- run libtoolize -f
- run automake
* Fri Oct 10 2003 mjancar@suse.cz
- initial version 0.4.14
